package JoelCastellanosAnimations;

import javafx.application.Application;
import javafx.event.ActionEvent;
import javafx.event.EventHandler;
import javafx.geometry.Insets;
import javafx.scene.Scene;
import javafx.scene.canvas.Canvas;
import javafx.scene.control.Button;
import javafx.scene.layout.HBox;
import javafx.scene.layout.StackPane;
import javafx.scene.layout.VBox;
import javafx.stage.Stage;


public class MainFrame extends Application  implements EventHandler<ActionEvent>
{
  private Button buttonDrawPivotLines;
  private Button buttonBouncingLines;
  private Button button3SetsOfLines;
  private Button button3SquareSpiral;
  private Button buttonRandomWalk;
  private Button buttonFireworks;
  private Button buttonDLA;

  private Canvas canvas;

  private Animation myAnimation;

  public static final int WINDOW_WIDTH = 940;
  public static final int WINDOW_HEIGHT = 870;

  @Override
  public void start(Stage primaryStage)
  {
    primaryStage.setTitle("Bouncing Lines");

    buttonDrawPivotLines = new Button("Pivot Lines");
    buttonDrawPivotLines.setOnAction(this);


    buttonBouncingLines = new Button("Bouncing Lines");
    buttonBouncingLines.setOnAction(this);

    button3SetsOfLines = new Button("3 Sets of Lines");
    button3SetsOfLines.setOnAction(this);

    button3SquareSpiral = new Button("Square Sprial");
    button3SquareSpiral.setOnAction(this);

    buttonRandomWalk = new Button("Random Walk");
    buttonRandomWalk.setOnAction(this);

    buttonFireworks = new Button("Fireworks");
    buttonFireworks.setOnAction(this);

    buttonDLA = new Button("DLA");
    buttonDLA.setOnAction(this);



    HBox formButtonBox = new HBox(10);
    formButtonBox.setPadding(new Insets(10, 10, 10, 10));
    formButtonBox.getChildren().addAll(buttonDrawPivotLines, buttonBouncingLines,
      button3SetsOfLines, button3SquareSpiral,
      buttonRandomWalk, buttonFireworks, buttonDLA);

    VBox pageBox = new VBox(10);

    canvas = new Canvas(Animation.DRAW_WIDTH, Animation.DRAW_HEIGHT);

    pageBox.getChildren().addAll(formButtonBox, canvas);

    StackPane root = new StackPane();


    root.getChildren().add(pageBox);
    primaryStage.setScene(new Scene(root, WINDOW_WIDTH, WINDOW_HEIGHT));
    primaryStage.show();

  }


  @Override
  public void handle(ActionEvent event)
  {
    Object source = event.getSource();

    if (myAnimation != null) myAnimation.stop();
    if (source == buttonDrawPivotLines)
    {
      myAnimation = new LineDrawAnimation(canvas);
      myAnimation.start();
    }

    else if (source == buttonBouncingLines)
    {
      myAnimation = new BouncingLine(canvas);
      myAnimation.start();
    }

    else if (source == button3SetsOfLines)
    {
      myAnimation = new BouncingSetsOfLines(canvas);
      myAnimation.start();
    }

    else if (source == button3SquareSpiral)
    {
      myAnimation = new SquareSprial(canvas);
      myAnimation.start();
    }

    else if (source == buttonRandomWalk)
    {
      myAnimation = new RandomWalk(canvas);
      myAnimation.start();
    }

    else if (source == buttonFireworks)
    {
      myAnimation = new Fireworks(canvas);
      myAnimation.start();
    }

    else if (source == buttonDLA)
    {
      //myAnimation = new DLA(canvas);
      myAnimation = new DLA_MosesGuillermoCampbellSantos(canvas);
      myAnimation.start();
    }


  }


  public static void main(String[] args)
  {
    launch(args);
  }
}
